@@ -34,13 +34,13 @@ class UploadJob:
 
     def __init__(self, bq_project, bq_dataset, table_name,
                  csv=None, columns=None, query=None, dsn=None, save_file_path=None, schema=None, date_column=None,
-                 set_date_conversion=None, set_logging=None, set_clear_csv_cache=None,
+                 set_date_conversion=None, set_logging=None, set_clear_csv_cache=None, set_testing=None,
                  first_name=None, surname=None):
         self.start_time = dt.datetime.now()
         self.upload_details = {'Error': ''}
         self.thg_log()
         self.account = Account(first_name, surname)
-        self.upload_setting = UploadSettings(set_date_conversion, set_logging, set_clear_csv_cache)
+        self.upload_setting = UploadSettings(set_date_conversion, set_logging, set_clear_csv_cache, set_testing)
         self.update_upload_setting()
         self.bq_project = bq_project
         self.bq_dataset = bq_dataset
@@ -187,19 +187,22 @@ class UploadJob:
             pass
 
     def int_convert(self):
-        self.upload_details['Progress'] = 'Converting int columns for upload.'
-        convert_columns = []
-        new_schema = []
-        new_df = self.df
-        for i in self.schema:
-            if i.field_type == 'INTEGER':
-                convert_columns.append(i.name)
+        if self.schema is not None:
+            self.upload_details['Progress'] = 'Converting int columns for upload.'
+            convert_columns = []
+            new_schema = []
+            new_df = self.df
+            for i in self.schema:
+                if i.field_type == 'INTEGER':
+                    convert_columns.append(i.name)
 
-        for i in convert_columns:
-            try:
-                new_df[i] = new_df[i].astype('Int64')
-            except Exception as e:
-                self.upload_details['Error'] = e
+            for i in convert_columns:
+                try:
+                    new_df[i] = new_df[i].astype('float')
+                    new_df[i] = new_df[i].astype('Int64')
+                except Exception as e:
+                    self.log('Failed To Convert Column: {} To INT'.format(i))
+                    self.upload_details['Error'] = e
 
     def get_credentials(self):
         """
@@ -208,7 +211,8 @@ class UploadJob:
         self.upload_details['Progress'] = 'Getting BQ Credentials'
         try:
             file = sys.modules['__main__'].__file__
-            self.upload_details['Location On VM'] = left(file, file.rfind('/')+1)
+            directory_name, file_name = os.path.split(os.path.abspath(file))
+            self.upload_details['Location On VM'] = str(directory_name)
             self.upload_details['Script Name'] = right(file, (len(file)-file.rfind('/'))-1)
             vm_os = 'Windows-2008ServerR2-6.1.7601-SP1'
             user_os = pl.platform()
@@ -563,67 +567,82 @@ class UploadJob:
         upload_details_job_config.source_format = 'CSV'
         save_path = self.save_file_path + "{}.csv"
         upload_details_df.to_csv(save_path.format('Upload_Details'), index=False, header=True)
-        with open(save_path.format('Upload_Details'), 'rb') as upload_details_file:
-            try:
-                upload_job = upload_details_bq_client.load_table_from_file(
-                    file_obj=upload_details_file, destination=upload_details_dataset_ref.table('VM_Audit'),
-                    job_config=upload_details_job_config)
-                upload_job.result()
-                print(upload_job.state)
-            except Exception as e:
-                self.log("Table Upload_Details failed to upload to VM_Audit")
-                self.log('Error: {}'.format(upload_job.errors[0]['message']))
-                self.log('Error: {}'.format(upload_job.errors[1]['message']))
-                self.upload_details['Error'] = e
+        if not self.upload_setting.testing:
+            with open(save_path.format('Upload_Details'), 'rb') as upload_details_file:
+                try:
+                    upload_job = upload_details_bq_client.load_table_from_file(
+                        file_obj=upload_details_file, destination=upload_details_dataset_ref.table('VM_Audit'),
+                        job_config=upload_details_job_config)
+                    upload_job.result()
+                    print(upload_job.state)
+                except Exception as e:
+                    self.log("Table Upload_Details failed to upload to VM_Audit")
+                    self.log('Error: {}'.format(upload_job.errors[0]['message']))
+                    self.log('Error: {}'.format(upload_job.errors[1]['message']))
+                    self.upload_details['Error'] = e
+
+            self.log('Removing Upload_Details CSV')
+            os.unlink(save_path.format('Upload_Details'))
+        else:
+            self.log('Testing live not storing results in BQ')
 
     def send_email(self):
         self.get_upload_details()
         self.upload_details['Job Status'] = 'Ran Unsuccessfully'
-        if self.upload_setting.vm_status:
-            if self.upload_setting.use_account:
-                outlook = win32.Dispatch('outlook.application')
-                email = outlook.CreateItem(0)
-                email.To = self.account.info['email']
-                email.Subject = 'VM Script: {} Failed to Run.'.format(self.upload_details['Script Name'])
-                if self.upload_details['Progress'] == 'Uploading to Big query.':
-                    if self.upload_details['GA Error'] is None:
-                        self.upload_details['GA Error'] = 'No GA Error'
-                    email.HTMLBody = """
-                        Time Ran: {3} <br><br>
-                        The Script located at: {0}{1} <br><br>
-                        The Script failed at: {4} <br><br>
-                        Failed to run successfully due to python error message: {2} <br><br>
-                        Failed to run successfully due to GA error message: {5}
-                        """.format(self.upload_details['Location On VM'], self.upload_details['Script Name'],
-                                   self.upload_details['Error'], self.upload_details['Run Date'],
-                                   self.upload_details['Progress'], self.upload_details['GA Error'])
-                else:
-                    email.HTMLBody = """
-                        Time Ran: {3} <br><br>
-                        The Script located at: {0}{1} <br><br>
-                        The Script failed at: {4} <br><br>
-                        Failed to run successfully due to error message: {2}
-                        """.format(self.upload_details['Location On VM'], self.upload_details['Script Name'],
-                                   self.upload_details['Error'], self.upload_details['Run Date'],
-                                   self.upload_details['Progress'])
-                email.Send()
+        if not self.upload_setting.testing:
+            if self.upload_setting.vm_status:
+                if self.upload_setting.use_account:
+                    outlook = win32.Dispatch('outlook.application')
+                    email = outlook.CreateItem(0)
+                    email.To = self.account.info['email']
+                    email.Subject = 'VM Script: {} Failed to Run.'.format(self.upload_details['Script Name'])
+                    if self.upload_details['Progress'] == 'Uploading to Big query.':
+                        if self.upload_details['GA Error'] is None:
+                            self.upload_details['GA Error'] = 'No GA Error'
+                        email.HTMLBody = """
+                            Time Ran: {3} <br><br>
+                            The Script located at: {0}{1} <br><br>
+                            The Script failed at: {4} <br><br>
+                            Failed to run successfully due to python error message: {2} <br><br>
+                            Failed to run successfully due to GA error message: {5}
+                            """.format(self.upload_details['Location On VM'], self.upload_details['Script Name'],
+                                       self.upload_details['Error'], self.upload_details['Run Date'],
+                                       self.upload_details['Progress'], self.upload_details['GA Error'])
+                    else:
+                        email.HTMLBody = """
+                            Time Ran: {3} <br><br>
+                            The Script located at: {0}{1} <br><br>
+                            The Script failed at: {4} <br><br>
+                            Failed to run successfully due to error message: {2}
+                            """.format(self.upload_details['Location On VM'], self.upload_details['Script Name'],
+                                       self.upload_details['Error'], self.upload_details['Run Date'],
+                                       self.upload_details['Progress'])
+                    email.Send()
 
 
 class UploadSettings:
 
-    def __init__(self, date_conversion, logging, clear_csv_cache):
+    def __init__(self, date_conversion, logging, clear_csv_cache, testing):
         if date_conversion is None:
             self.date_conversion = False
         else:
             self.date_conversion = date_conversion
+
         if logging is None:
             self.logging = True
         else:
             self.logging = logging
+
         if clear_csv_cache is None:
             self.clear_csv_cache = True
         else:
             self.clear_csv_cache = clear_csv_cache
+
+        if testing is None:
+            self.testing = False
+        else:
+            self.testing = testing
+
         self.use_save_file_path = False
         self.vm_status = False
         self.use_account = False
@@ -641,6 +660,8 @@ class UploadSettings:
             print("""   Date Conversion: {}""".format(self.date_conversion))
             print("""   Logging: {}""".format(self.logging))
             print("""   Clear CSV cache: {}""".format(self.clear_csv_cache))
+            print("""   Testing: {}""".format(self.testing))
+
             insert_line()
             print('')
         else:
